@@ -10,12 +10,11 @@ Arg::LongOption g_longOpts[] =
     Arg::LongOption{"data",         'D'},
     Arg::LongOption{"death-age",    'a'},
     Arg::LongOption{"help",         'h'},
-    Arg::LongOption{"nCases",       'n'},
+    Arg::LongOption{"cases",        'c'},
     Arg::LongOption{"one-analysis", 'o'},
     Arg::LongOption{"parameters",   'P'},
     Arg::LongOption{"rounds",       'R'},
     Arg::LongOption{"sensitivity",  'S'},
-//    Arg::LongOption{"totalrisk",    'T'},
     Arg::LongOption{"tumor-age",    't'},
     Arg::LongOption{"verbose",      'V'},
     Arg::LongOption{"version",      'v'},
@@ -27,7 +26,7 @@ auto const *g_longEnd = g_longOpts + size(g_longOpts);
 int main(int argc, char **argv)
 try
 {
-    Arg const &arg = Arg::initialize("a:B:C:D:hn:oP:R:S:t:vV",
+    Arg const &arg = Arg::initialize("a:B:c:C:D:hoP:R:S:t:vV",
                                       g_longOpts, g_longEnd, argc, argv);
     arg.versionHelp(usage, Icmake::version, arg.option('o') ? 0 : 1);
 
