@@ -3,10 +3,11 @@
 
 void Mammo::insertBeta(ostream &out, size_t begin, size_t end) const
 {
-    out << setw(13) << ' ';
-            
+    out << ' ';
+
+    Globals::setPrecision(out, 2);
+
     for (; begin != end; ++begin)
-        out << "   " << begin << ": " << d_beta[begin] << ',';
+        out << begin << ": " << d_beta[begin] << ",  ";
 
-    out.put('\n');
 }
