@@ -21,6 +21,10 @@ void Options::alter(int optChar, std::string const &value)
             setBase(value);
         break;
 
+        case 'c':
+            lastCase(value);
+        break;
+
         case 'C':
             d_specified += 'C';
             replaceHome(d_config = value);
@@ -30,10 +34,6 @@ void Options::alter(int optChar, std::string const &value)
             setFile(d_dataFile = value, 'D', true);
         break;
 
-        case 'n':
-            lastCase(value);
-        break;
-
         case 'o':
             throw Exception{} << 
                 "`one-scenario' cannot be used in scenario specifications";
