@@ -10,8 +10,6 @@ void Options::inspect() const
         throw Exception{} << "Options --death-age and --tumor-age "
                 "must both be specified";
 
-    if (count != 0 and d_specified.find('n') != string::npos)
+    if (count != 0 and d_specified.find('c') != string::npos)
         throw Exception{} << "--case and --death_age are mutually exclusive";
-
-
 }
