@@ -3,7 +3,7 @@
 
 void Options::lastCase(string const &value)
 {
-    d_specified += 'n';
+    d_specified += 'c';
     d_lastCase = stoul(value);
 }
 
