@@ -52,8 +52,8 @@ class Options
         std::string const &sensitivityFile() const;             // .h
         bool specificAges() const;                              // .h
 
-        void naturalDeathAge(double &deathAge) const; 
-        void tumorAge(double &tumorAge) const;
+        void fixedNaturalDeathAge(double &deathAge) const; 
+        void fixedTumorAge(double &tumorAge) const;
         size_t lastCase() const;                                // .h
 
                                                 // try to change this option's
