@@ -32,7 +32,7 @@ Options::Options()
     if (d_arg.option(&value, 't'))
         setTumorAge(value);
 
-    if (d_arg.option(&value, 'n'))
+    if (d_arg.option(&value, 'c'))
         lastCase(value);
 
     inspect();
