@@ -1,7 +1,7 @@
 //#define XERR
 #include "options.ih"
 
-void Options::tumorAge(double &tumorAge) const
+void Options::fixedTumorAge(double &tumorAge) const
 {
     if (d_specified.find('t') != string::npos)
         tumorAge = d_tumorAge;
